@@ -1,4 +1,4 @@
-from cmss.plugin_base import CMSPluginBase
+from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
 from django.utils.translation import ugettext_lazy as _
 
